pub struct Camera<S, P, D, Sm, K>where
S: RealField + Copy,
P: ProjectionModel<S>,
D: DistortionModel<S>,
Sm: SensorModel<S>,
K: IntrinsicsModel<S>,{
pub proj: P,
pub dist: D,
pub sensor: Sm,
pub k: K,
/* private fields */
}Expand description
A composable camera model: projection -> distortion -> sensor -> intrinsics.
Fields
proj: PProjection model (e.g. pinhole).
dist: DDistortion model (e.g. Brown-Conrady).
sensor: SmSensor model (e.g. identity or tilted homography).
k: KIntrinsics model (K).
Implementations
Sourceimpl<S, P, D, Sm, K> Camera<S, P, D, Sm, K>where
S: RealField + Copy,
P: ProjectionModel<S>,
D: DistortionModel<S>,
Sm: SensorModel<S>,
K: IntrinsicsModel<S>,
impl<S, P, D, Sm, K> Camera<S, P, D, Sm, K>where
S: RealField + Copy,
P: ProjectionModel<S>,
D: DistortionModel<S>,
Sm: SensorModel<S>,
K: IntrinsicsModel<S>,
Sourcepub fn new(proj: P, dist: D, sensor: Sm, k: K) -> Self
pub fn new(proj: P, dist: D, sensor: Sm, k: K) -> Self
Build a camera from its component models.
Sourcepub fn project_point_c(&self, p_c: &Vector3<S>) -> Option<Point2<S>>
pub fn project_point_c(&self, p_c: &Vector3<S>) -> Option<Point2<S>>
Project a 3D point in camera coordinates into pixel coordinates.
Returns None if the point is behind the camera or not projectable.
Sourcepub fn project_point(&self, p_c: &Point3<S>) -> Option<Point2<S>>
pub fn project_point(&self, p_c: &Point3<S>) -> Option<Point2<S>>
Project a 3D point in camera coordinates into pixel coordinates.
This is a convenience wrapper around project_point_c.
Sourcepub fn backproject_pixel(&self, px: &Point2<S>) -> Ray<S>
pub fn backproject_pixel(&self, px: &Point2<S>) -> Ray<S>
Backproject a pixel to a point on the z = 1 plane in camera coordinates.