CameraFixMask

Struct CameraFixMask 

pub struct CameraFixMask {
    pub intrinsics: IntrinsicsFixMask,
    pub distortion: DistortionFixMask,
}
Combined mask for camera calibration parameters.

Groups intrinsics and distortion masks for convenient configuration.

Fields

intrinsics: IntrinsicsFixMask

Mask for intrinsics (fx, fy, cx, cy).

distortion: DistortionFixMask

Mask for distortion (k1, k2, k3, p1, p2).

Implementations

Source

impl CameraFixMask

pub fn all_fixed() -> Self

Create a mask that fixes all camera parameters.

pub fn all_free() -> Self

Create a mask that allows all camera parameters to be optimized, except k3 which is fixed by default.

pub fn truly_all_free() -> Self

Create a mask that allows all camera parameters to be optimized, including k3.