pub struct CameraFixMask {
pub intrinsics: IntrinsicsFixMask,
pub distortion: DistortionFixMask,
}Expand description
Combined mask for camera calibration parameters.
Groups intrinsics and distortion masks for convenient configuration.
Fields
intrinsics: IntrinsicsFixMaskMask for intrinsics (fx, fy, cx, cy).
distortion: DistortionFixMaskMask for distortion (k1, k2, k3, p1, p2).
Implementations
Sourceimpl CameraFixMask
impl CameraFixMask
Sourcepub fn all_free() -> Self
pub fn all_free() -> Self
Create a mask that allows all camera parameters to be optimized, except k3 which is fixed by default.
Sourcepub fn truly_all_free() -> Self
pub fn truly_all_free() -> Self
Create a mask that allows all camera parameters to be optimized, including k3.